@@ -1,24 +1,9 @@
-/********************************************************************
- KSld - the KDE Screenlocker Daemon
- This file is part of the KDE project.
+/*
+SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-Copyright (C) 2014 Martin Gräßlin <mgraesslin@kde.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
-#ifndef LOGIND_H
-#define LOGIND_H
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
+#pragma once
 
 #include <QDBusConnection>
 #include <QDBusPendingCallWatcher>
@@ -82,5 +67,3 @@ private:
     const QString *m_managerInterface;
     const QString *m_sessionInterface;
 };
-
-#endif
